# Crawfish
![PyPI - License](https://img.shields.io/pypi/l/django-crawfish)
![PyPI](https://img.shields.io/pypi/v/django-crawfish)
![Gitlab pipeline status](https://img.shields.io/gitlab/pipeline/crawfordleeds/crawfish)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-crawfish)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-crawfish)

This project contains a collection of code I re-use for most of my Django projects and is not [yet] well suited
for public consumption.

## Documentation

### Install

```bash
pip install django-crawfish
```

## Development

Install package dependencies:

```bash
pip install -e .
```

Install dev dependencies:

```bash
pip install -e '.[dev]'
```
